# Modified version of example.py from http://sourceforge.net/projects/windrose/
# Uses Numpy to load in a Datawell his ( Historical Spectra ) csv file and 
# plots binned Hm0 and directions, only takes account of peak direction and 
# overall Hm0 value

# author: James Morrison
# license: 'CeCILL-B'
# website: http://bitbucket.org/jamesmorrison/waverose

from windrose import WindroseAxes
from matplotlib import pyplot as plt
import matplotlib.cm as cm
from numpy.random import random
from numpy import arange
import os
import numpy as np

bin_values = np.array([0,0.25,0.5,0.75,1,1.5,2,3,4,6,8])

class WaveRose:

    def __init__(self, sig_wave_height, direction, title, ylim=20, y_label='Hm0 (metres)',bin_values=bin_values, size=(5,5.7), interval=3):    
        self.ylim = ylim
        self.size = size
        self.interval = interval
        self.bin_values = bin_values
        self.plot(sig_wave_height, direction, title, y_label)

    def new_axes(self):
        fig = plt.figure(figsize=self.size, dpi=300, facecolor='w', edgecolor='w')
        rect = [0.1, 0.1, 0.8, 0.8]
        ax = WindroseAxes(fig, rect, axisbg='w')
        fig.add_axes(ax)
        ax.set_ybound(lower=0, upper=self.ylim)
        return ax, fig
        
    def set_legend(self, ax, y_label):
        l = ax.legend(axespad=-0.10, title=y_label)
        l.title = 'Hm0 in metres'
        plt.setp(l.get_texts(), fontsize=8)
        
    def plot(self, sig_wave_height, direction, title, y_label):
        wd = direction
        wd = wd.astype(np.float64)
        sig_wave_height = sig_wave_height.astype(np.float64)
        #windrose like a stacked histogram with normed (displayed in percent) results
        ax, fig = self.new_axes()
        ax.bar(wd, sig_wave_height, normed=True, opening=1, edgecolor='white', bins=self.bin_values, nsector=32)
        ax.set_title( title + "\n Radial values indicate percentage of occurences") 
        tick_range = range(0,self.ylim,self.interval)
        ax.yaxis.set_ticks(tick_range)
        ax.yaxis.set_ticklabels(tick_range)
        plt.ylim(0,self.ylim)
        self.set_legend(ax, y_label)
        plt.savefig( title, dpi=300)
        plt.plot()        
